@@ -5,14 +5,10 @@ from enum import Enum
 from functools import wraps
 from typing import Any
 from typing import Callable
-from typing import Dict
-from typing import List
 
-from dynaconf.base import RESERVED_ATTRS
 from dynaconf.base import Settings
 from dynaconf.loaders.base import SourceMetadata
 
-
 __all__ = [
     "hookable",
     "EMPTY_VALUE",
@@ -22,11 +18,11 @@ __all__ = [
     "MethodValue",
     "Action",
     "HookableSettings",
+    "post_hook",
 ]
 
 
-class Empty:
-    ...
+class Empty: ...
 
 
 EMPTY_VALUE = Empty()
@@ -81,17 +77,9 @@ def hookable(function=None, name=None):
         ):
             return fun(self, *args, **kwargs)
 
-        # Create an unhookable (to avoid recursion)
+        # Create an unhook-able (to avoid recursion)
         # temporary settings to pass to the hooked function
-        temp_settings = Settings(
-            dynaconf_skip_loaders=True,
-            dynaconf_skip_validators=True,
-        )
-        allowed_keys = self.__dict__.keys() - set(RESERVED_ATTRS)
-        temp_data = {
-            k: v for k, v in self.__dict__.items() if k in allowed_keys
-        }
-        temp_settings._store.update(temp_data)
+        temp_settings = TempSettingsHolder(self)
 
         def _hook(action: str, value: HookValue) -> HookValue:
             """executes the hooks for the given action"""
@@ -308,3 +296,80 @@ class HookableSettings(Settings):
     @hookable
     def get(self, *args, **kwargs):
         return Settings.get(self, *args, **kwargs)
+
+
+class TempSettingsHolder:
+    """Holds settings to be passed down to hooks.
+    To save runtime resources initialize a copy of it only if accessed.
+    """
+
+    _settings = None
+
+    def __init__(self, settings):
+        self._original_settings = settings
+
+    def _initialize(self):
+        if self._settings is None:
+            self._settings = Settings(
+                dynaconf_skip_loaders=True,
+                dynaconf_skip_validators=True,
+                _store=self._original_settings._store._safe_copy(),
+            )
+
+    def __getattr__(self, attr):
+        self._initialize()
+        return getattr(self._settings, attr)
+
+    def __getitem__(self, item):
+        self._initialize()
+        return self._settings[item]
+
+    def __setitem__(self, item, value):
+        self._initialize()
+        self._settings[item] = value
+
+    def __iter__(self):
+        self._initialize()
+        return iter(self._settings)
+
+    def __contains__(self, item):
+        self._initialize()
+        return item in self._settings
+
+    def __setattr__(self, attr, value):
+        if attr in ["_original_settings", "_settings"]:
+            super().__setattr__(attr, value)
+        else:
+            self._initialize()
+            setattr(self._settings, attr, value)
+
+
+def post_hook(function: Callable) -> Callable:
+    """This decorator marks a function as a post hook.
+    This works by adding the _dynaconf_hook attribute to the function,
+    then the python loader, when reading the module, will look for
+    this attribute and register the function as a post_hook for the settings.
+
+    e.g: On a settings file with .py extension:
+
+    from dynaconf import post_hook
+    @post_hook
+    def set_log_handlers(settings) -> dict:
+        data = {}  # data to be merged into settings
+
+        # conditionals
+        if (logging := settings.get('LOGGING')) is not None:
+            # do something with logging
+            # add it back to data
+            data['LOGGING'] = logging
+        return data
+    """
+    try:
+        function._dynaconf_hook = True  # type: ignore
+        function._called = False  # type: ignore
+        function._dynaconf_hook_source = function.__module__  # type: ignore
+    except (AttributeError, TypeError):
+        raise TypeError(
+            "post_hook decorator must be applied to a function or method."
+        )
+    return function
