@@ -4,7 +4,10 @@ from __future__ import annotations
 
 import json
 import sys
+from contextlib import suppress
 from functools import partial
+from importlib.metadata import PackageNotFoundError
+from importlib.metadata import version
 from pathlib import PosixPath
 from typing import Any
 from typing import Callable
@@ -28,11 +31,21 @@ if TYPE_CHECKING:  # pragma: no cover
 
 # Dumpers config
 
-json_pretty = partial(json.dump, indent=2)
-json_compact = json.dump
+json_pretty = partial(json.dump, indent=2, default=str)
+json_compact = partial(json.dump, default=str)
+
+
+def yaml_dumper_with_defaults(data: dict, text_stream: TextIO) -> None:
+    """Easier way to get YAML dumper to handle unseralizable types"""
+    yaml = YAML()
+    # let JSON handle unserializable types and then load it back
+    data = json.loads(json.dumps(data, default=str))
+    yaml.default_flow_style = False
+    yaml.dump(data, text_stream)
+
 
 builtin_dumpers = {
-    "yaml": YAML().dump,
+    "yaml": yaml_dumper_with_defaults,
     "json": json_pretty,
     "json-compact": json_compact,
 }
@@ -312,7 +325,7 @@ def _get_data_by_key(
     key_dotted_path: str,
     default: Any = None,
     sep="__",
-):
+) -> Any:
     """
     Returns value found in data[key] using dot-path str (e.g, "path.to.key").
     Raises KeyError if not found
@@ -344,3 +357,127 @@ def _get_data_by_key(
         if not default:
             raise KeyError(f"Path not found in data: {key_dotted_path!r}")
         return default
+
+
+def get_debug_info(
+    settings: Settings | LazySettings,
+    verbosity: int = 0,
+    key: str | None = None,
+) -> dict:
+    """Returns a dict with debug info about the settings object"""
+
+    if key:
+        verbosity = 2
+
+    def filter_by_key(data: dict) -> dict:
+        """If key is not None, filter dict keeping only the key"""
+        if key:
+            try:
+                return {key: _get_data_by_key(data, key)}
+            except KeyError:
+                return {}
+        return data
+
+    def build_loading_history() -> list[dict]:
+        _data = []
+        for (
+            source_metadata,
+            source_data,
+        ) in settings._loaded_by_loaders.items():
+            _real_data = filter_by_key(source_data)
+            if verbosity == 0:
+                _data.append(
+                    {
+                        "loader": source_metadata.loader,
+                        "identifier": source_metadata.identifier,
+                        "data": len(_real_data),
+                    }
+                )
+            elif verbosity == 1:
+                _data.append(
+                    {
+                        "loader": source_metadata.loader,
+                        "identifier": source_metadata.identifier,
+                        "data": list(_real_data.keys()),
+                    }
+                )
+            else:
+                _data.append(
+                    {
+                        "loader": source_metadata.loader,
+                        "identifier": source_metadata.identifier,
+                        "data": _real_data,
+                    }
+                )
+        return _data
+
+    def build_loaded_hooks():
+        _data = []
+        for hook, hook_data in settings._loaded_hooks.items():
+            _real_data = filter_by_key(hook_data.get("post", {}))
+            if verbosity == 0:
+                _data.append(
+                    {
+                        "hook": str(hook),
+                        "data": len(_real_data),
+                    }
+                )
+            elif verbosity == 1:
+                _data.append(
+                    {
+                        "hook": str(hook),
+                        "data": list(_real_data.keys()),
+                    }
+                )
+            else:
+                _data.append(
+                    {
+                        "hook": str(hook),
+                        "data": _real_data,
+                    }
+                )
+        return _data
+
+    data = {
+        "versions": {
+            "dynaconf": version("dynaconf"),
+        },
+        "root_path": settings._root_path,
+        "validators": [str(v) for v in settings.validators],
+        "core_loaders": settings._loaders,
+        "loaded_files": settings._loaded_files,
+        "history": build_loading_history(),
+        "post_hooks": [str(h) for h in settings._post_hooks],
+        "loaded_hooks": build_loaded_hooks(),
+    }
+    for name in ["django", "flask", "fastapi", "starlette"]:
+        with suppress(PackageNotFoundError):
+            data["versions"][name] = version(name)
+
+    if settings.get("ENVIRONMENTS_FOR_DYNACONF"):
+        data["environments"] = list(settings.get("ENVIRONMENTS_FOR_DYNACONF"))
+        data["loaded_envs"] = settings._loaded_envs
+
+    if key:
+        data["current"] = {key: settings.get(key)}
+    return data
+
+
+def print_debug_info(
+    settings: Settings | LazySettings,
+    *,
+    dumper: DumperPreset | DumperType | None = None,
+    verbosity: int = 0,
+    key: str | None = None,
+):
+    """Calls dumper with settings debug info"""
+    dumper = dumper or "yaml"
+    if isinstance(dumper, str):
+        dumper = builtin_dumpers.get(dumper)
+        if dumper is None:
+            raise OutputFormatError(
+                f"The desired format is not available: {dumper!r}"
+            )
+
+    data = get_debug_info(settings, verbosity, key)
+    dumper(data, sys.stdout)
